@@ -6,8 +6,10 @@ from chordparser.notes import Note
 from chordparser.keys import Key
 from chordparser.scales import Scale
 from chordparser.chords import Chord
+from chordparser.quality import Quality
+from chordparser.roman import Roman
 
 
 __author__ = 'Titus Ong'
 __email__ = 'titusongyl@gmail.com'
-__version__ = '0.2.2'
+__version__ = '0.3.7'
