@@ -11,17 +11,10 @@ SE = scales_editor.ScaleEditor()
 CE = chords_editor.ChordEditor()
 
 
-@pytest.mark.parametrize(
-    "value", [1, len, True, [], ()])
-def test_chord_typeerror(value):
-    with pytest.raises(TypeError):
-        CE.create_chord(value)
-
-
 @pytest.mark.parametrize(
     "value", ["1", "H", "\u266fG"])
 def test_chord_valueerror(value):
-    with pytest.raises(ValueError):
+    with pytest.raises(SyntaxError):
         CE.create_chord(value)
 
 
@@ -29,74 +22,36 @@ def test_chord_valueerror(value):
     "value, root", [
         ('C', NE.create_note('C')),
         ('E\u266f', NE.create_note('E\u266f')),
-        ]
-    )
+    ]
+)
 def test_chord_root(value, root):
     new_chord = CE.create_chord(value)
     assert new_chord.root == root
 
 
-@pytest.mark.parametrize(
-    "string, quality", [
-        ('C', 'major'),
-        ('Cm', 'minor'),
-        ('Cdim', 'diminished'),
-        ('C+', 'augmented'),
-        ('C7', 'dominant seventh'),
-        ('C5', 'power'),
-        ('c7', 'minor seventh'),
-        ('Cminmaj9', 'minor-major ninth'),
-        ('Caugmaj11', 'augmented-major eleventh'),
-        ('Caugb13', 'augmented minor thirteenth'),
-        ('Cmaj9', 'major ninth'),
-        ('Cdim7', 'diminished seventh'),
-        ('C\u00f87', 'half-diminished seventh'),
-        ('Cm9', 'minor ninth'),
-        ]
-    )
-def test_quality(string, quality):
-    new_chord = CE.create_chord(string)
-    assert new_chord.quality == quality
-
-
-@pytest.mark.parametrize(
-    "string, quality", [
-        ('Cmb5', 'diminished'),
-        ('CM7#5', 'augmented-major seventh'),
-        ('Cmin7dim5', 'half-diminished seventh'),
-        ]
-    )
-def test_quality_alt5(string, quality):
-    new_chord = CE.create_chord(string)
-    assert new_chord.quality == quality
-
-
-@pytest.mark.parametrize(
-    "string, sus", [
-        ('Csus2', 2),
-        ('Csus', 4),
-        ('Csus4', 4),
-        ('C', None),
-        ]
-    )
-def test_sus(string, sus):
-    c = CE.create_chord(string)
-    assert c.sus == sus
+def test_quality():
+    c = CE.create_chord("Cminmaj7")
+    assert "minor major seventh" == str(c.quality)
 
 
 @pytest.mark.parametrize(
     "string, add", [
-        ('Cadd13', ['13']),
-        ('cadd2#6', ['2', '\u266f6']),
-        ('cminmaj9b11', ['\u266d11']),
+        ('Cadd13', [('', 13)]),
+        ('cadd2#6', [('', 2), ('\u266f', 6)]),
+        ('cminmaj9b11', [('\u266d', 11)]),
         ('C', None),
-        ]
-    )
+    ]
+)
 def test_add(string, add):
     c = CE.create_chord(string)
     assert c.add == add
 
 
+def test_add_2():
+    c = CE.create_chord("C")
+    assert c.add is None
+
+
 def test_parse_error():
     with pytest.raises(SyntaxError):
         c = CE.create_chord('Cadd21')
@@ -107,24 +62,29 @@ def test_parse_error():
         ('C', None),
         ('C/G', NE.create_note('G')),
         ('C/G#', NE.create_note('G\u266f')),
-        ]
-    )
+    ]
+)
 def test_bass(string, bass):
     c = CE.create_chord(string)
     assert c.bass == bass
 
 
+def test_bass_2():
+    c = CE.create_chord("C")
+    assert None is c.bass
+
+
 @pytest.mark.parametrize(
     "degree, quality", [
         (7, 'diminished'),
         (4, 'major'),
         (6, 'minor'),
-        ]
-    )
+    ]
+)
 def test_diatonic(degree, quality):
     s = SE.create_scale('C', 'major')
     c = CE.create_diatonic(s, degree)
-    assert c.quality == quality
+    assert str(c.quality) == quality
 
 
 @pytest.mark.parametrize(
@@ -132,12 +92,12 @@ def test_diatonic(degree, quality):
         (7, 'diminished'),
         (4, 'major'),
         (6, 'minor'),
-        ]
-    )
+    ]
+)
 def test_diatonic_2(degree, quality):
     s = KE.create_key('C', 'major')
     c = CE.create_diatonic(s, degree)
-    assert c.quality == quality
+    assert str(c.quality) == quality
 
 
 @pytest.mark.parametrize("degree", [0, len])
@@ -150,17 +110,12 @@ def test_diatonic_value_error(degree):
 @pytest.mark.parametrize(
     "input, output", [
         ("hey", "hey"), (None, '')
-        ]
-    )
+    ]
+)
 def test_xstr(input, output):
     assert CE._xstr(input) == output
 
 
-def test_change_chord_error():
-    with pytest.raises(TypeError):
-        CE.change_chord(len)
-
-
 def test_change_chord_root():
     o = CE.create_chord('C')
     n = CE.create_chord('D')
@@ -170,66 +125,38 @@ def test_change_chord_root():
 def test_change_chord_q():
     o = CE.create_chord('C')
     n = CE.create_chord('Cminmajb9')
-    assert n == CE.change_chord(o, quality="minor-major minor ninth")
-
-
-@pytest.mark.parametrize(
-    "quality", [
-        "powr", "power ninth", "major sixth", "augmented major ninth", "augmented minor tenth", "major minor ninth ten",
-        ]
-    )
-def test_change_chord_q_error(quality):
-    o = CE.create_chord('C')
-    with pytest.raises(ValueError):
-        CE.change_chord(o, quality=quality)
-
-
-def test_change_chord_sus():
-    o = CE.create_chord('Csus2')
-    n = CE.create_chord('C')
-    assert n == CE.change_chord(o, sus=False)
-
-
-def test_change_chord_sus_error():
-    o = CE.create_chord('C')
-    with pytest.raises(ValueError):
-        CE.change_chord(o, sus=3)
+    assert n == CE.change_chord(o, quality="minmajb9")
 
 
 def test_change_chord_add():
     o = CE.create_chord('Cadd9')
     n = CE.create_chord('Caddb2add9')
-    assert n == CE.change_chord(o, add=['b2'])
-
-
-def test_change_chord_add_error():
-    o = CE.create_chord('C')
-    with pytest.raises(ValueError):
-        CE.change_chord(o, add=['b22'])
+    assert n == CE.change_chord(o, add='b2')
 
 
 def test_change_chord_rem():
     o = CE.create_chord('Caddb2')
     n = CE.create_chord('C')
-    assert n == CE.change_chord(o, remove=['b2'])
+    assert n == CE.change_chord(o, remove='b2')
 
 
 def test_change_chord_rem_2():
     o = CE.create_chord('Caddb2add6add9')
     n = CE.create_chord('C')
     assert n == CE.change_chord(o, remove=True)
+    assert None is o.add
 
 
 def test_change_chord_rem_error():
     o = CE.create_chord('C')
-    with pytest.raises(ValueError):
-        CE.change_chord(o, remove=['b2'])
+    with pytest.raises(IndexError):
+        CE.change_chord(o, remove='b2')
 
 
 def test_change_chord_rem_error_2():
     o = CE.create_chord('Cb2')
     with pytest.raises(ValueError):
-        CE.change_chord(o, remove=['b22'])
+        CE.change_chord(o, remove='b22')
 
 
 def test_change_chord_bass():
@@ -242,3 +169,11 @@ def test_change_chord_bass_2():
     o = CE.create_chord('Cadd9/G')
     n = CE.create_chord('Cadd9')
     assert n == CE.change_chord(o, bass=False)
+    assert None is o.bass
+
+
+def test_change_chord_not_inplace():
+    o = CE.create_chord("Csus4add9/G")
+    n = CE.change_chord(o, bass='G', inplace=False)
+    assert n == o
+    assert n is not o
