@@ -17,19 +17,12 @@ def test_scale_keys(key):
 
 @pytest.mark.parametrize(
     "root, mode, submode", [('C', 'phrygian', None)]
-    )
+)
 def test_scale_key_args(root, mode, submode):
     new_scale = SE.create_scale(root, mode, submode)
     assert new_scale.key == KE.create_key(root, mode, submode)
 
 
-@pytest.mark.parametrize(
-    "key", [1, True, len])
-def test_scale_keys_typeerror(key):
-    with pytest.raises(TypeError):
-        SE.create_scale(key)
-
-
 def test_change_scale():
     o = SE.create_scale('C', 'major', None)
     n = SE.create_scale('D', 'minor', 'harmonic')
@@ -41,6 +34,8 @@ def test_change_scale_2():
     n = SE.create_scale('D\u266d', 'minor', 'melodic')
     assert n == SE.change_scale(o, 'D\u266d', 'minor', None)
 
-def test_change_scale_error():
-    with pytest.raises(TypeError):
-        SE.change_scale(len)
+
+def test_change_scale_not_inplace():
+    o = SE.create_scale("C")
+    n = SE.change_scale(o, root="C", inplace=False)
+    assert n is not o
